@@ -1,8 +1,5 @@
 package Apache::Singleton::Process;
-{
-  $Apache::Singleton::Process::VERSION = '0.14';
-}
-
+$Apache::Singleton::Process::VERSION = '0.16';
 # ABSTRACT: One instance per One Process
 
 use strict;
@@ -10,21 +7,32 @@ use base 'Apache::Singleton';
 
 no strict 'refs';
 
+my %INSTANCES;
+
 sub _get_instance {
     my $class = shift;
-    my $global = "$class\::_instance";
-    return $$global;
+
+    $class = ref $class || $class;
+
+    return $INSTANCES{$class};
 }
 
 sub _set_instance {
     my($class, $instance) = @_;
-    my $global = "$class\::_instance";
-    $$global = $instance;
+
+    $class = ref $class || $class;
+
+    $INSTANCES{$class} = $instance;
+}
+
+END {
+    # dereferences and causes orderly destruction of all instances
+    undef(%INSTANCES);
 }
 
 1;
 
-
+__END__
 
 =pod
 
@@ -34,7 +42,7 @@ Apache::Singleton::Process - One instance per One Process
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -71,7 +79,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
